Rohde & Schwarz SMBV100B Vector Signal Generator RsSmbv instrument driver Version 4.80.0.0009

Release Notes:

Version 4.80.0.9
- Default HwInterface repcap is 0 (empty command suffix)

Version 4.80.0.8
- Added arb_files interface

Version 4.80.0.7
- Included GNSS subsystem

Version 4.80.0.2
- First released version